# Raspinet

Raspinet is a Python library for simplifying networking between Raspberry Pis.

## Features

- Discover devices on the local network.
- Connect to and communicate with devices.
- Send and receive messages and files.

## Installation

You can install Raspinet via pip:

```sh
pip install raspinet
